@@ -4,13 +4,13 @@
 require 'base64'
 require 'fiber'
 require 'find'
-require 'pstore'
 require 'singleton'
 require 'tmpdir'
 require 'yaml'
 require 'zlib'
 
 # External gems
+require 'clonefile'
 require 'concurrent-ruby'
 require 'json_schema'
 require 'ddmetrics'
@@ -21,13 +21,6 @@ require 'slow_enumerator_tools'
 require 'tty-platform'
 require 'zeitwerk'
 
-# External gems (optional)
-begin
-  require 'clonefile'
-rescue LoadError
-  # ignore
-end
-
 module Nanoc
   module Core
     # Similar to `nil` except that it can only be compared against using
