@@ -15,7 +15,7 @@ EOS
   end
 
   it 'does not expose #path on @item' do
-    site = Nanoc::Int::SiteLoader.new.new_from_cwd
-    expect { site.compile }.to raise_error(NoMethodError, /undefined method .*path.* for .*Nanoc::BasicItemView/)
+    site = Nanoc::Core::SiteLoader.new.new_from_cwd
+    expect { Nanoc::Core::Compiler.compile(site) }.to raise_error(NoMethodError, /undefined method .*path.* for .*Nanoc::Core::BasicItemView/)
   end
 end
